function c = deltrial (c, tset)

%@cortex/private/deltrial.m
%
% removes trials from a @cortex object
%
% W A R N I N G !!!
% =================================================================
% this function alters the @cortex object, so you'd better know
% what you are doing; the source data file, however, is unaffected; 
% save the object to a dump file to make changes persistent.
% =================================================================
%
% Syntax 1: COBJ.DELTRIAL = KEY
% Syntax 2: COBJ.DELTRIAL = TSET
%
% Where:
%  COBJ: an existing @cortex object
%  KEY:  a key from a @key object to select the trials to remove
%  TSET: a vector explicitly containing those trial numbers
%
% - This function only works on unlocked objects;
% - To avoid confusion, delete all trials you want to
%   get rid of with a single call to this function;
% - This function still does not support v.3 stuff, so do NOT
%   use it if the object contains spike channels, LFPs, etc.
%
% Last modified: 22 Apr 03

% 12 May 00: last unnoted changes
% 30 Nov 02: function moved to private, can only be accessed
%            via OOP-like syntax
% 11 Dec 02: multiple bugs fixed; @key support added
%  5 Feb 03: for loops rewritten: it seems to work now...
% 22 Apr 03: serious bugfix! c.cluster_bank' in for j loop

if isa (tset, 'rules')
   if prod(tset.size)>1, error ('single rule required'); end
   ts = trialset (c, tset);
elseif isa (tset, 'key')
   if tset.len > 1, error ('simple key required'); end
   ts = trialset (c, tset);
else
   ts = tset;
end

c.cond_no        (ts) = [];
c.repeat_no      (ts) = [];
c.block_no       (ts) = [];
c.eog_rate       (ts) = [];
c.KHz_resolution (ts) = [];
c.trial_type     (ts) = [];
c.exp_response   (ts) = [];
c.response       (ts) = [];
c.rel_trial      (ts) = [];

c.times       (ts, :) = [];
c.codes       (ts, :) = [];

curr_spos = 1;
newspikes = uint32([]);
kt = ones (1, c.trials); % trials to be kept
kt (ts) = 0;             % trials to be discarded

if ~isempty (c.spikes)
   for i = find(kt)
      for j = 1:length (c.cluster_bank)
         ssta = c.spike_start (i,j);
         if ssta
            send = c.spike_end (i,j);
            newspikes = [newspikes; c.spikes(ssta:send)];
            c.spike_start (i,j) = curr_spos;
            c.spike_end   (i,j) = curr_spos + send - ssta;
            curr_spos = c.spike_end (i,j) + 1;
         end
      end
   end
   c.spikes = newspikes;
   c.spike_start (ts,:) = [];
   c.spike_end (ts,:) = [];
end

c.trials = length (c.cond_no);

c.changemode = 3;
disp('CHANGES WERE APPLIED TO @CORTEX OBJECT');