function varargout = nexf_cont(fid, header_offset)
% Read continuous variable from a .nex file
%
% varargout = nex_cont(fid, header_offset)
%
% INPUT:
%   fid - fileID
%   header_offset - header offset of the continuous variable
%
%        continuous (a/d) data come in fragments. Each fragment has a timestamp
%        and a number of a/d data points. The timestamp corresponds to
%        the time of recording of the first a/d value in this fragment.           
% OUTPUT:
%   ad - array of a/d values
%              OR
%   adfreq - frequency of continuous data collection (Hz)
%   ts - fragment timestamp
%   fn - number of data points in each fragment

%   nf - number of fragments

adfreq=0; n=0; ts=0; fn=0; d=0;

fseek(fid, header_offset+72, 'bof');
data_offset = fread(fid, 1, 'int32');
nf = fread(fid, 1, 'int32');
dummy = fread(fid, 32, 'char');
adfreq = fread(fid, 1, 'double');
adtomv = fread(fid, 1, 'double');
n = fread(fid, 1, 'int32');
fseek(fid, data_offset, 'bof');
ts = fread(fid, [1 nf], 'int32');
fn = fread(fid, [1 nf], 'int32');
ad = fread(fid, [1 n], 'int16');

fn(nf+1) = n;
fn = diff(fn);

if nargout == 1
    varargout = {ad};
elseif nargout == 3
    varargout = {adfreq, ts, fn};
else
    error('The number of outputs of this function is either 1 or 3');
end