function [a, aa] = subsref (c, s)

% @cortex/subsref.m
%
% Subscript handling routine for @cortex objects
%
% The user of the class does not need to know how it works.
%
% Last modified: 3 Dec 04

% 10 aug 98: support for arrays of @cortex objects added
% 21 apr 99: changemode
% 13 jun 99: rel_trial added
% 10 may 00: lock/unlock status
% 19 May 00: partial trial_type retrieval was missing
% 20 May 00: ver(sion) field added
% 14 Nov 02: support for tfr & mfr added
% 15 Nov 04: 'given' instead of 'expected' response
%  3 Dec 04: c.view(k) support added


%%%%%%%%%%%%%%%%%%%%%%%% how many levels of referencing?
switch length (s)
   case 1
      a = one (c, s);
   case 2
      a = two (c, s);
   case 3
      a = three (c, s);
   otherwise
      error ('too many levels of subreferencing');
end

%%%%%%%%%%%%%%%%%%%%%%%% one referencing level.
function a = one (c, s)

if s.type == '.'
   if length (c) > 1
      error ('array of objects treated as one');
   end
   a = getwholefield (c, s.subs);
elseif s.type == '()'
   ind = s.subs;
   a = c (ind{1});
else
   error ('can''t use {} with @cortex objects');
end
return

%%%%%%%%%%%%%%%%%%%%%%%% two referencing levels.
function a = two (c, s)

if s(1).type == '.' & s(2).type == '()'
   a = getfieldsubset (c, s(1).subs, s(2).subs);
elseif s(1).type == '()' & s(2).type == '.'
   i = s(1).subs;
   a = one (c(i{1}), s(2));
else
   error ('bad syntax');
end
return

%%%%%%%%%%%%%%%%%%%%%%%% three referencing levels.
%% e.g., cobj(3).codes(3,:)

function a = three (c, s)

if s(1).type == '()' & s(2).type == '.' & s(3).type == '()'
   i = s(1).subs;
   a = getfieldsubset (c(i{1}), s(2).subs, s(3).subs);
else
   error ('bad syntax');
end
return

%%%%%%%%%%%%%%%%%%%%%%%% get the entire array
function a = getwholefield (c, f)

expwarn = 'exp warning!';

switch minifield(f)
   case 'vie'
      cortview (c);
      disp ('browsing object...');
      a = [];
   case 'nam'
      a = c.name;
   case 'ver'
      a = c.version;
   case 'tri'
      a = c.trials;
   case 'rel'
      a = c.rel_trial;
   case 'con'
      a = c.cond_no;
   case 'blo'
      a = c.block_no;
   case 'res'
      a = c.response;
   case 'rep'
      a = c.repeat_no;
   case 'eog'
      a = c.eog_rate;
   case 'sac'  % in the unlikely event that somebody was using the meaningless c.saccade_error
      a = c.eog_rate;
   case 'khz'
      a = c.KHz_resolution;
   case 'swi'  % in the unlikely event that somebody was using the meaningless c.switch_trial
      a = c.KHz_resolution;
   case 'typ'
      a = c.trial_type;
   case 'exp'
      warning ('Use of dot-property ''exp'' is deprecated. Please use one of:')
      disp ('- ''typ'' if you want to retrieve the trial type, aka the ''expected response''')
      disp ('- ''giv'' if you want to retrieve the given response, aka the ''response''')
      a = c.exp_response;
   case 'giv'
      a = c.exp_response;
   case 'tim'
      a = c.times;
   case 'cod'
      a = c.codes;
   case 'ban'
      a = c.cluster_bank;
   case 'clu'
      a = c.cluster_bank;
   case 'cha'
      switch c.changemode
         case 0
            a = 'unchanged, locked';
         case 1
            a = 'changed, locked';
         case 2
            a = 'unchanged, unlocked';
         case 3
            a = 'changed, unlocked';
      end
   case 'loc'
      if c.changemode < 2
         a = 'true';
      else
         a = 'false';
      end
   case 'unl'
      if c.changemode > 1
         a = 'true';
      else
         a = 'false';
      end
   otherwise
      error ('field does not exist');
end
return

%%%%%%%%%%%%%%%%%%%%%%%% get only part of the array
function a = getfieldsubset (c, f, ind)

switch minifield(f)
   case 'vie'
      k = ind{1};
      if ~isa (k, 'key'), error ('@key object required'); end
      cortview (c, k);
      a = [];
   case 'sav'
      save (c, ind{1});
      a = ind{1};
   case 'tri'
      error ('cobj.trials is a scalar');
   case 'rel'
      a = c.rel_trial(ind{1});
   case 'con'
      a = c.cond_no(ind{1});
   case 'blo'
      a = c.block_no(ind{1});
   case 'res'
      a = c.response(ind{1});
   case 'rep'
      a = c.repeat_no(ind{1});
   case 'sac'  % in the unlikely event that somebody was using the meaningless c.saccade_error
      a = c.eog_rate(ind{1});
   case 'eog'
      a = c.eog_rate(ind{1});
   case 'swi'  % in the unlikely event that somebody was using the meaningless c.switch_trial
      a = c.KHz_resolution(ind{1});
   case 'typ'
      a = c.trial_type(ind{1});
   case 'khz'
      a = c.KHz_resolution(ind{1});
   case 'exp'
      warning ('Use of dot-property ''exp'' is deprecated. Please use one of:')
      disp ('- ''typ'' if you want to retrieve the trial type, aka the ''expected response''')
      disp ('- ''giv'' if you want to retrieve the given response, aka the ''response''')
      a = c.exp_response(ind{1});
   case 'giv'
      a = c.exp_response(ind{1});
   case 'tim'
      a = c.times(ind{1}, ind{2});
   case 'cod'
      a = c.codes(ind{1}, ind{2});
   case 'ban'
      a = c.cluster_bank(ind{1});
   case 'clu'
      a = c.cluster_bank(ind{1});
   case 'tfr'
      switch length (ind)
         case 2
            a = trialfiringrate (c, ind{1}, ind{2});
         case 3
            a = trialfiringrate (c, ind{1}, ind{2}, ind{3});
         otherwise
            error ('wrong number of arguments');
      end
   case 'mfr'       
      switch length (ind)
         case 2
            [a, aa] = meanfiringrate (c, ind{1}, ind{2});
         case 3
            [a, aa] = meanfiringrate (c, ind{1}, ind{2}, ind{3});
         otherwise
            error ('wrong number of arguments');
      end
   otherwise
      error ('field does not exist');
end
return