function [X, Y] = trialeogs (c, t)

% @CORTEX/TRIALEOGS   eog (eye) XY positions from a single trial
%                     in a @cortex object
%
% [POSX,POSY] = TRIALEOGS(COBJ,TRIAL);
%
% where
% COBJ:   the @cortex object
% TRIAL:  a single trial
% POSX:   horizontal projections of eye positions;
% POSY:   vertical   projections of eye positions;
%         each matrix has COL samples (in dva) by ROW trials;
%         values are time-locked on the cue(s) specified in the key
%
% Last modified: 07 Feb 06

errifinvalidtrial (c, t);
e = c.eog;
if e.dva==0, error ('@cortex object does not contain EOG data'); end
[X, Y] = raweyepos(c, t);
if nargout==1, X = [X Y]; end