function [x y] = trialepps (c, trial)

% @CORTEX/TRIALEPPS   returns a matrix of EPP values from a single trial
%                    in a @cortex object
%
% Syntax 1: XY = TRIALEPPS(COBJ,TRIAL);
% Syntax 2: [X Y] = TRIALEPPS(COBJ,TRIAL);
%
% where
% COBJ:  the @cortex object
% EPPM:  matrix of EPP values (one row per trial, one column per sample;
%        values are time-locked on the cue(s) specified in the key
% TIME:  the corresponding time scale
% XY:    data from the two EPP channels
%
% Last modified: 07 Feb 06

% Created on 7 Feb 06

errifinvalidtrial (c, trial);
e = c.epp;
if ~e.rate, error ('object does not contain EPP data'); end
first = e.ptr(trial);
last  = e.ptr(trial+1)-1;
x = double(e.ch1 (first:last));
y = double(e.ch2 (first:last));
if nargout==1, x = [x y]; end
