function sp = addfactor (sp, label, levels, keys)

%@SPIX/ADDFACTOR defines and stores a factor in a @spix object
%
%    SP = ADDFACTOR(SP,LABEL,LEVELS,KEYS) stores in SP criteria to
%    perform ANOVAs. A factor has a LABEL (a string, e.g., 'color'),
%    two or more LEVELS (a cell array of strings, e.g., {'red' 'blue'
%    'green' 'yellow'}), and key sets that are used by SPIX/ANOVAN to
%    select the appropriate spike trains (a cell array of key #s,
%    e.g., {1:4 5:8 9:12 13:16}.
%
%    Note that the keys belonging to each of the levels are passed to
%    ADDFACTOR in each of the cells in KEYS, such that:
%    length(LEVELS)==length(KEYS).
%    
%Last modified 26 Nov 04

% 26 Nov 04: help text, argument checking

error (nargchk (4, 4, nargin));
error (NOTstring (label, 'LABEL'));
if ~iscell(levels) | ~iscell(keys) | length(levels) ~= length(keys)
   error ('LEVELS, KEYS must be cell arrays of equal length');
end

fi = sp.nfactors + 1;
sp.factors(fi).label = label;
sp.factable (fi,sp.k.len)=0;

for le = 1:length(levels)
   sp.factors(fi).levels(le).label = levels{le};
   sp.factors(fi).levels(le).keys = keys{le};
   sp.factable (fi,keys{le}) = le;
end
sp.nfactors = fi;
