function sp = addgroup (sp, label, keys)

%ADDGROUP defines and stores a group of keys in a @spix object
%
%   Analyses restricted to a GROUP of keys return distinct values for
%   each key in the group. On the other hand, analyses run using a key
%   COMBO as a restriction combine together trials selected by all
%   keys in the combo, and return only one result (see ADDCOMBO).
%
%   SP = ADDGROUP(SP,LABEL,KEYS) stores in SP the subset of keys
%   specified in KEYS. KEYS can be a key label, a set of key labels
%   (in a cell array of strings), one of 'none' 'all' 'first' 'last',
%   or a numeric array specifying the ordinal numbers of the keys that
%   will be part of the group; the string LABEL is the name of the
%   subset.
%
%   SP = ADDGROUP(SP,LABEL) a group named LABEL is created with all
%   currently selected keys
%
%   Note that if LABEL already exists as a group name, the new group
%   will replace the existing one
%
%Modified: 26 Nov 04

% 26 Apr 03, by Giuseppe Bertini
% 30 May 03: lotsa fixes
% 26 Nov 04: help text

if nargin > 2
   ks = parsegrouping (sp.k, keys);
   if isempty(ks), error ('none of the requested keys exists'); end
   disp ([num2str(length(ks)) ' keys']);
else
   disp ('all the currently "included" keys')
   ks = sp.inkeys;
end

sset = lbl2idx (sp.groups, label);
if sset
   disp ('redefining an existing group');
else
   disp ('creating a new group');
   sset = sp.ngroups + 1;
   sp.groups(sset).label = label;
   sp.ngroups = sset;
end

sp.groups(sset).keys = ks;