function sp = addsubset (sp, label, units)

%@SPIX/ADDSUBSET defines and stores a subset of units in a @spix object
%
%   SP = ADDSUBSET(SP,LABEL,UNITS)  stores in SP the subset of units
%   specified in UNITS. UNITS can be a unit label, a set of unit
%   labels  (in a cell array of strings), one of 'none' 'all' 'first'
%   'last', or a numeric array specifying the ordinal numbers of the
%   units that will be part of the subset; the string LABEL is the
%   name of the subset.
%
%   SP = ADDSUBSET(SP,LABEL) a subset named LABEL is created with all
%   currently selected units
%
%   Note that if LABEL already exists as a subset name, the new subset
%   will replace the existing one
%
%Last modified: 26 Nov 04

% changes since 21 Aug 03:
% 26 Nov 04: help text

if nargin == 2
   disp ('all the currently "included" units')
   uni = sp.inclunits;
elseif nargin == 3
   uni = parsegrouping (sp.info, units);
   disp ([num2str(length(uni)) ' units']);
else
   error ('wrong number of arguments');
end

error (NOTstring (label, 'LABEL'));
sset = lbl2idx (sp.subsets, label);
if sset
   disp ('replacing an existing subset');
else
   disp ('in a new subset');
   sset = length(sp.subsets) + 1;
   sp.subsets(sset).label = label;
   sp.nsubs = sset;
end

sp.subsets(sset).units = uni;
