function [lat, tri] = latency (c, r, g, s, f)

%LATENCY  time intervals between two events in a subset of trials
%
% Syntax 1: [LAT,TRI] = LATENCY(COBJ,KEY,START,FINISH)
% Syntax 2: [LAT,TRI] = LATENCY(COBJ,TSET,START,FINISH)
%
% COBJ:  @cortex object
% KEY:   a single key from a @key object
% TSET:  an array of trials
% START, FINISH: the encodes to compute latencies on
% LAT:   an array of computed latencies in ms
% TRI:   a matching array with the trials from which latencies
%        were computed. Multiple latencies per trial are allowed.
%
% Last modified 27 Oct 04

% 16 Apr 00: bug fixed
% 11 May 00: group and trialset support added
% 11 Aug 00: prevent crashes if one of 2 events is not found,
%    as pointed out by JHR. Code is slower but safer.
%    Argout TRI added: array of trial nos. from which latencies
%    were computed. Multiple latencies per trial are allowed.
% 10 Oct 02: @key support added
% 27 Oct 04: help text fixes; argument check

switch nargin
case 4
   start = g;
   finish = s;
   if isa (r, 'rules') | isa (r, 'key')
      yestrials = trialset (c, r);
   elseif isnumvector(r)
      yestrials = r;
   else
      error ('2nd argument should be either a key or a numeric vector');
   end
case 5
   start = s;
   finish = f;
	yestrials = trialset (c, r, g);
otherwise
   error ('wrong number of arguments');
end

error (NOTscalar (start ));
error (NOTscalar (finish));

lat = [];
tri = [];

for i = yestrials
   t1 = find (c.codes (i,:) == start);
   t2 = find (c.codes (i,:) == finish);
   mi = min ([length(t1) length(t2)]);
   if mi
      ti = c.times (i, t2(1:mi)) - c.times (i, t1(1:mi));
      lat = [lat, ti];
      tri = [tri, repmat(i, 1, mi)];
   end
end
